@@ -6,12 +6,13 @@ from .linguee import LingueeTranslator
 from .mymemory import MyMemoryTranslator
 from .yandex import YandexTranslator
 from .qcri import QCRI
+from .deepl import DeepL
 from .detection import single_detection, batch_detection
 
 
 __author__ = """Nidhal Baccouri"""
 __email__ = 'nidhalbacc@gmail.com'
-__version__ = '1.2.4'
+__version__ = '1.2.5'
 
 __all__ = [GoogleTranslator,
            PonsTranslator,
@@ -19,5 +20,6 @@ __all__ = [GoogleTranslator,
            MyMemoryTranslator,
            YandexTranslator,
            QCRI,
+           DeepL,
            single_detection,
            batch_detection]
