@@ -6,7 +6,8 @@ BASE_URLS = {
     "YANDEX": "https://translate.yandex.net/api/{version}/tr.json/{endpoint}",
     "LINGUEE": "https://www.linguee.com/",
     "MYMEMORY": "http://api.mymemory.translated.net/get",
-    "QCRI": "https://mt.qcri.org/api/v1/{endpoint}?"
+    "QCRI": "https://mt.qcri.org/api/v1/{endpoint}?",
+    "DEEPL": "https://api.deepl.com/{}/"
 }
 
 GOOGLE_CODES_TO_LANGUAGES = {
